@@ -12,9 +12,8 @@ The all_stubs folder should be mapped/symlinked to the micropython_stubs/stubs r
 #   part of the MicroPython project, http://micropython.org/
 #   Copyright (c) 2019 Damien P. George
 
-import csv
+
 import glob
-import logging
 # locating frozen modules :
 # tested on MicroPython v1.12 - v1.13
 # - 1.16 - using manifests.py, include can specify kwargs
@@ -22,29 +21,30 @@ import logging
 # - 1.12 - using manifests.py, possible also include content of /port/modules folder ?
 # - 1.11 and older - include content of /port/modules folder if it exists
 import os
-import pkgutil
 import re
 import shutil
-import tempfile
 import warnings
-from collections import defaultdict
 from pathlib import Path  # start moving from os & glob to pathlib
-from typing import Optional
+from typing import Optional, Union
+
+from loguru import logger as log
+from packaging.version import Version
+
+from stubber.utils.config import CONFIG
+from stubber.utils.repos import match_lib_with_mpy
 
 # Classes and functions from makemanifest to ensure that the manifest.py files can be processed
-from . import basicgit as git
 from . import makemanifest_2 as makemanifest
 from . import utils
-from .utils.config import CONFIG
 
-log = logging.getLogger(__name__)
+# # log = logging.getLogger(__name__)
 # log.setLevel(level=logging.DEBUG)
 
 # globals
 FAMILY = "micropython"
 
 
-def get_frozen(stub_folder: str, version: str, mpy_folder: Optional[str] = None, lib_folder: Optional[str] = None):
+def get_frozen(stub_folder: str, version: str, mpy_path: Optional[Union[Path, str]] = None, lib_path: Optional[Union[Path, str]] = None):
     """
     get and parse the to-be-frozen .py modules for micropython to extract the static type information
      - requires that the MicroPython and Micropython-lib repos are checked out and available on a local path
@@ -52,35 +52,35 @@ def get_frozen(stub_folder: str, version: str, mpy_folder: Optional[str] = None,
     """
 
     current_dir = os.getcwd()
-    if not mpy_folder:
-        mpy_folder = "./micropython"
-    if not lib_folder:
-        lib_folder = "./micropython-lib"
+    if not mpy_path:
+        mpy_path = "./micropython"
+    if not lib_path:
+        lib_path = "./micropython-lib"
     if not stub_folder:
         stub_folder = "{}/{}_{}_frozen".format(CONFIG.stub_path, FAMILY, utils.clean_version(version, flat=True))
     # get the manifests of the different ports and boards
-    mpy_folder = Path(mpy_folder).absolute().as_posix()
-    lib_folder = Path(lib_folder).absolute().as_posix()
+    mpy_path = Path(mpy_path).absolute().as_posix()
+    lib_path = Path(lib_path).absolute().as_posix()
     stub_folder = Path(stub_folder).absolute().as_posix()
 
     # manifest.py is used for board specific and daily builds
     # manifest_release.py is used for the release builds
-    manifests = glob.glob(mpy_folder + "/ports/**/manifest.py", recursive=True) + glob.glob(
-        mpy_folder + "/ports/**/manifest_release.py", recursive=True
+    manifests = glob.glob(mpy_path + "/ports/**/manifest.py", recursive=True) + glob.glob(
+        mpy_path + "/ports/**/manifest_release.py", recursive=True
     )
 
     # remove any manifests  that are below one of the virtual environments (venv) \
     # 'C:\\develop\\MyPython\\micropython\\ports\\esp32\\build-venv\\lib64\\python3.6\\site-packages\\pip\\_vendor\\distlib\\manifest.py'
     # and skip the manifest used for coverage tests
     manifests = [m for m in manifests if not "venv" in str(m) and Path(m).parent.name != "coverage"]
-
-    if len(manifests) > 0:
-        log.info("MicroPython v1.12 and newer")
-        get_frozen_from_manifest(manifests, stub_folder, mpy_folder, lib_folder, version)
+    # FIXME check vor version , not count of manifests
+    if version in ["latest", "master"] or Version(version) >= Version("1.12"):
+        log.debug("MicroPython v1.12 and newer")
+        get_frozen_from_manifest(manifests, stub_folder, mpy_path, lib_path, version)
     else:
-        log.info("MicroPython v1.11, older or other")
+        log.debug("MicroPython v1.11, older or other")
         # others
-        get_frozen_folders(stub_folder, mpy_folder, lib_folder, version)
+        get_frozen_folders(stub_folder, mpy_path, lib_path, version)
     # restore cwd
     os.chdir(current_dir)
 
@@ -105,7 +105,7 @@ def get_frozen_folders(stub_folder: str, mpy_folder: str, lib_folder: str, versi
             mpy_board = "GENERIC"
 
         dest_path = os.path.join(stub_folder, mpy_port, mpy_board)
-        log.info("freeze_internal : {:<30} to {}".format(script, dest_path))
+        log.debug("freeze_internal : {:<30} to {}".format(script, dest_path))
         # ensure folder, including possible path prefix for script
         os.makedirs(dest_path, exist_ok=True)
         # copy file
@@ -115,7 +115,7 @@ def get_frozen_folders(stub_folder: str, mpy_folder: str, lib_folder: str, versi
                 targets.append(dest_path)
         except OSError as e:
             ## Ignore errors that are caused by reorganisation of Micropython-lib
-            # print(e)
+            # log.exception(e)
             warnings.warn("unable to freeze {} due to error {}".format(e.filename, str(e)))
 
     for dest_path in targets:
@@ -156,39 +156,6 @@ def get_target_names(path: str) -> tuple:
     return mpy_port, mpy_board
 
 
-def read_micropython_lib_commits(filename="data/micropython_tags.csv"):
-    """
-    Read a csv with the micropython version and matchin micropython-lib commit-hashes
-    these can be used to make sure that the correct micropython-lib version is checked out.
-
-    TODO: it would be nice if micropython-lib had matching commit-tags
-    
-        git for-each-ref --sort=creatordate --format '%(refname) %(creatordate)' refs/tags
-    """
-    data = pkgutil.get_data(__name__, filename)
-    if not data:
-        raise Exception(f"Resource {filename} not found")
-    version_commit = defaultdict()  # lgtm [py/multiple-definition]
-    with tempfile.NamedTemporaryFile(prefix="tags", suffix=".csv", mode="w+t") as ntf:
-        ntf.file.write(data.decode(encoding="utf8"))
-        ntf.file.seek(0)
-        # read the csv file using DictReader
-        reader = csv.DictReader(ntf.file, skipinitialspace=True)  # dialect="excel",
-        rows = list(reader)
-        # create a dict version --> commit_hash
-        version_commit = {row["version"].split("/")[-1]: row["lib_commit_hash"] for row in rows if row["version"].startswith("refs/tags/")}
-    # add default
-    version_commit = defaultdict(lambda: "master", version_commit)
-    return version_commit
-
-
-def match_lib_with_mpy(version_tag: str, lib_folder: str):
-    micropython_lib_commits = read_micropython_lib_commits()
-    # Make sure that the correct micropython-lib release is checked out
-    log.info(f"Matching repo's:  Micropython {version_tag} needs micropython-lib:{micropython_lib_commits[version_tag]}")
-    return git.checkout_commit(micropython_lib_commits[version_tag], lib_folder)
-
-
 def get_frozen_from_manifest(
     manifests,
     stub_folder: str,
@@ -222,35 +189,37 @@ def get_frozen_from_manifest(
 
     # Include top-level inputs, to generate the manifest
     for manifest in manifests:
-        log.info("Manifest: {}".format(manifest))
-        makemanifest.path_vars["PORT_DIR"] = ""
-        makemanifest.path_vars["BOARD_DIR"] = ""
+        log.debug("Manifest: {}".format(manifest))
+        port_dir = board_dir = ""
 
         # check BOARD AND PORT pattern
         matches = re.search(regex_port_board, manifest)
         if matches:
             # port and board
-            makemanifest.path_vars["PORT_DIR"] = matches.group("port") or ""
-            makemanifest.path_vars["BOARD_DIR"] = matches.group("board") or ""
+            port_dir = matches.group("port") or ""
+            board_dir = matches.group("board") or ""
             if os.path.basename(matches.group("board")) == "manifest":
-                makemanifest.path_vars["BOARD_DIR"] = ""
+                board_dir = ""
         else:
             # TODO: Variants
             matches = re.search(regex_port_board, manifest)  # BOARD AND VARIANT
             if matches:
                 # port and variant
-                makemanifest.path_vars["PORT_DIR"] = matches.group("port") or ""
-                makemanifest.path_vars["BOARD_DIR"] = matches.group("board") or ""
+                port_dir = matches.group("port") or ""
+                board_dir = matches.group("board") or ""
                 if os.path.basename(matches.group("board")) == "manifest":
-                    makemanifest.path_vars["BOARD_DIR"] = ""
+                    board_dir = ""
             else:
                 # just port
                 matches = re.search(regex_port, manifest)
                 if matches:
-                    makemanifest.path_vars["PORT_DIR"] = matches.group("port") or ""
+                    port_dir = matches.group("port") or ""
 
-        port_name = os.path.basename(makemanifest.path_vars["PORT_DIR"])
-        board_name = os.path.basename(makemanifest.path_vars["BOARD_DIR"])
+        makemanifest.path_vars["PORT_DIR"] = port_dir
+        makemanifest.path_vars["BOARD_DIR"] = board_dir
+
+        port_name = Path(port_dir).name
+        board_name = Path(board_dir).name
 
         if board_name == "":
             board_name = "GENERIC"
@@ -267,17 +236,14 @@ def get_frozen_from_manifest(
 
         try:
             makemanifest.include(manifest)
-        except makemanifest.FreezeError as er:
+        except (makemanifest.FreezeError, NameError) as er:
             log.error('freeze error executing "{}": {}'.format(manifest, er.args[0]))
 
-        # NOTE: compensate for expicitly omittest task.py from freeze manifest 
+        # NOTE: compensate for expicitly omittest task.py from freeze manifest
         if (freeze_path / "uasyncio").exists():
             # copy task.py from micropython\extmod\uasyncio\task.py to stub_folder
-            log.info(f"add missing : uasyncio/task.py to {freeze_path}")
+            log.debug(f"add missing : uasyncio/task.py to {freeze_path}")
             shutil.copy(str(Path(mpy_folder) / "extmod" / "uasyncio" / "task.py"), str(freeze_path / "uasyncio"))
 
-
         # make a module manifest
         utils.make_manifest(Path(makemanifest.stub_dir), FAMILY, port=port_name, board=board_name, version=version, stubtype="frozen")
-
-
