@@ -35,7 +35,7 @@ to do:
 # ref: https://regex101.com/codegen?language=python
 # https://regex101.com/r/Ni8g2z/2
 
-import logging
+from loguru import logger as log
 import re
 from typing import Dict, List, Union
 
@@ -54,7 +54,7 @@ __all__ = [
 
 
 # logging
-log = logging.getLogger(__name__)
+# # log = logging.getLogger(__name__)
 
 # all possible Types needed
 TYPING_IMPORT: List[str] = [
@@ -168,7 +168,7 @@ def simple_candidates(
         result = BASE.copy()
         result["type"] = type
         result["confidence"] = rate * dist_rate(i)  # OK
-        log.debug(f" - found '{kw}' at position {i} with rating {dist_rate(i)}")
+        log.trace(f" - found '{kw}' at position {i} with rating {dist_rate(i)}")
         candidates.append(result)
     return candidates
 
@@ -230,7 +230,7 @@ def compound_candidates(
             result["type"] = f"{type}"
         confidence = confidence * dist_rate(i)  # distance weighting
         result["confidence"] = confidence
-        log.debug(f" - found '{kw}' at position {i} with confidence {confidence} rating {dist_rate(i)}")
+        log.trace(f" - found '{kw}' at position {i} with confidence {confidence} rating {dist_rate(i)}")
 
         candidates.append(result)
     return candidates
